@@ -72,3 +72,17 @@ tristan_group.add_argument(
     help="Number of binnes images",
     type=int,
 )
+
+
+def add_tristan_spec(detector, tristanSpec):
+    """
+    Add metadata specific to LATRD Tristan to detector scope.
+
+    Args:
+        detector (scope_extract):      Scope defining the detector
+        tristanSpec (scope_extract):   Scope defining Tristan specific input
+    """
+    for k, v in tristanSpec.__dict__.items():
+        if "__phil" in k:
+            continue
+        detector.__inject__(k, v)
